====
Base
====

Python objects
==============

.. automodule:: bodhi.messages.schemas.base
   :exclude-members: body_schema, __module__
   :members:
   :show-inheritance:
   :special-members:
   :undoc-members:
